==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-appearance/translations/lxqt-config-appearance_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="147"/>
        <source>GTK themes</source>
        <translation>GTK temaer</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="148"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; har blitt overskrevet.&lt;/p&gt;&lt;p&gt;Du kan finne en kopi av dine gamle innstillinger i &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Standard skrift for brukergrensesnittet</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Skriftnavn:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Skriftstørrelse:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Fet kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>De følgende innstillingene påvirker bare nystartede programmer</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Bruk antialiasfonter</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Skrifthinting stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Litt</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Skrifthinting</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Oppløsning (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Subpiksel antialiasing:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Utseendeinnstillinger</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Symboltema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>KDE tillegget for XDG symboltemaer -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Fargelegg symboler basert på widgetstil (palett)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Bruk i stedet for brukerdefinert skrivebordsbakgrunn</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Utseendeinnstillinger</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Icons Theme</source>
        <translation>Symboltema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Cursor</source>
        <translation>Peker</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="42"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Velg GTK tema (GTK-innstillingsfiler blir overskrevet!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="62"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3-tema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="72"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2-tema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="82"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>For å oppnå likhet mellom temaene, velg enten lignende stil/tema (hvis tilgjengelig) på tvers av listene eller velg &apos;gtk2&apos; Qt stil (hvis tilgjengelige) for å herme GTK temaer.

Pass på at &apos;xsettingsd&apos; er installert for å hjelpe GTK-programmer å bruke temaer med en gang.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="99"/>
        <source>Toolbar button style:</source>
        <translation>Knappstil for verktøylinje:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="107"/>
        <source>Only display the icon</source>
        <translation>Bare vis symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>Only display the text</source>
        <translation>Bare vis teksten</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="117"/>
        <source>The text appears beside the icon</source>
        <translation>Tekst vises ved siden av symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>The text appears under the icon</source>
        <translation>Tekst vises under symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="127"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="135"/>
        <source>Activate item on single click</source>
        <translation>Aktiver ved enkeltklikk</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="145"/>
        <source>Qt Style</source>
        <translation>Qt-stil</translation>
    </message>
</context>
</TS>

==> lxqt-config-0.17.1.tar.xz: lxqt-config-0.17.1/lxqt-config-appearance/translations/lxqt-config-appearance_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Klikk for å endre farge.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Velg farge</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="148"/>
        <source>GTK themes</source>
        <translation>GTK temaer</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="149"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; har blitt overskrevet.&lt;/p&gt;&lt;p&gt;Du kan finne en kopi av dine gamle innstillinger i &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Standard skrift for brukergrensesnittet</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Skriftnavn:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Skriftstørrelse:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Fet kursiv</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>De følgende innstillingene påvirker bare nystartede programmer</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Bruk antialiasfonter</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Skrifthinting stil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Litt</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Skrifthinting</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Oppløsning (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Subpiksel antialiasing:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Utseendeinnstillinger</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Symboltema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>KDE tillegget for XDG symboltemaer -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Fargelegg symboler basert på widgetstil (palett)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Bruk i stedet for brukerdefinert skrivebordsbakgrunn</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Utseendeinnstillinger</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Icons Theme</source>
        <translation>Symboltema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Cursor</source>
        <translation>Peker</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt-fargepalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Noen Qt-stiler kan ignorere disse fargene.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Vindu:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Visning:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Markering:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Lenke:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Vindustekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Vis tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Valgt tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Besøkt lenke:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="227"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Forvalgt fargepalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="254"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Velg GTK tema (GTK-innstillingsfiler blir overskrevet!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3-tema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2-tema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="294"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>For å oppnå likhet mellom temaene, velg enten lignende stil/tema (hvis tilgjengelig) på tvers av listene eller velg &apos;gtk2&apos; Qt stil (hvis tilgjengelige) for å herme GTK temaer.

Pass på at &apos;xsettingsd&apos; er installert for å hjelpe GTK-programmer å bruke temaer med en gang.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="311"/>
        <source>Toolbar button style:</source>
        <translation>Knappstil for verktøylinje:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="319"/>
        <source>Only display the icon</source>
        <translation>Bare vis symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="324"/>
        <source>Only display the text</source>
        <translation>Bare vis teksten</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="329"/>
        <source>The text appears beside the icon</source>
        <translation>Tekst vises ved siden av symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="334"/>
        <source>The text appears under the icon</source>
        <translation>Tekst vises under symbolet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="339"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="347"/>
        <source>Activate item on single click</source>
        <translation>Aktiver ved enkeltklikk</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt-stil</translation>
    </message>
</context>
</TS>
